==> kubernetes-model-networking-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/IngressClassSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IngressClassSpecBuilder extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluentImpl<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecBuilder>{
  public IngressClassSpecBuilder() {
    this(false);
  }
  public IngressClassSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new IngressClassSpec(), validationEnabled);
  }
  public IngressClassSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressClassSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IngressClassSpec(), validationEnabled);
  }
  public IngressClassSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec instance) {
    this(fluent, instance, false);
  }
  public IngressClassSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withController(instance.getController()); 
    fluent.withParameters(instance.getParameters()); 
    this.validationEnabled = validationEnabled; 
  }
  public IngressClassSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec instance) {
    this(instance,false);
  }
  public IngressClassSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withController(instance.getController()); 
    this.withParameters(instance.getParameters()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec build() {
    IngressClassSpec buildable = new IngressClassSpec(fluent.getController(),fluent.getParameters());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressClassSpecBuilder that = (IngressClassSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-networking-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/networking/v1beta1/IngressClassSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IngressClassSpecBuilder extends io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluentImpl<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecBuilder>{
  public IngressClassSpecBuilder() {
    this(false);
  }
  public IngressClassSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new IngressClassSpec(), validationEnabled);
  }
  public IngressClassSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressClassSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IngressClassSpec(), validationEnabled);
  }
  public IngressClassSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec instance) {
    this(fluent, instance, false);
  }
  public IngressClassSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withController(instance.getController()); 
    fluent.withParameters(instance.getParameters()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IngressClassSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec instance) {
    this(instance,false);
  }
  public IngressClassSpecBuilder(io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withController(instance.getController()); 
    this.withParameters(instance.getParameters()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.networking.v1beta1.IngressClassSpec build() {
    IngressClassSpec buildable = new IngressClassSpec(fluent.getController(),fluent.getParameters());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressClassSpecBuilder that = (IngressClassSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
